function PeakFeatures
%This function serves to plot the peak features for a range of Irradiation
%strengths from 0 to 50 J/m^2, for a population of 51 cells at each
%irradiation value.

IrradiationValues = linspace(0,50,10);
CellNumber = zeros(3,length(IrradiationValues));
PeakTimes = zeros(3,length(IrradiationValues));
PeakTimesSTDEV = zeros(3,length(IrradiationValues)); 
PeakAmplitudes = zeros(3,length(IrradiationValues));
PeakAmplitudesSTDEV = zeros(3,length(IrradiationValues));
ScalingTimes = zeros(1,length(IrradiationValues));

for ll = 1:length(IrradiationValues)
    Irradiation = IrradiationValues(ll);
    
    Damage = Irradiation.*0.11;
    
    %Mean delay time tau dependent on irradiation level
    FriedmanTau = 68; %From Friedman et al. paper
    
    %Linear Fit
    TDNull = 34.8; TDPrime = 1.3; %From regression to Friedman et al. data, Rsquare = 0.9481
    TD = TDNull+TDPrime.*Irradiation;
    
    %2nd degree polynomial fit
    %From regression to Friedman et al. data, Rsquare=0.9702
    TDNull = 39.0; TDPrime = 0.599; TDPrimePrime = 0.0135;
    TD = TDPrimePrime.*Irradiation.^2 + TDPrime.*Irradiation + TDNull;
    
    %Mean tau from Friedman et al. paper relation
    MeanTau = FriedmanTau./4.35.*TD./(FriedmanTau+TD);
    
    ElapsedTime = 250;
    NumberOfCells = 51;
    global sNull lagtime
    
    TOneContainer = zeros(2,NumberOfCells);
    TTwoContainer = TOneContainer;
    TThreeContainer = TOneContainer;
    
    subplot(2,2,1:2)
    hold off
    for kk = 1:NumberOfCells;
        NumberOfCells-kk+1
        
        tau = MeanTau.*(1+random('norm',0,0.03)); %Delay in minutes
        sNull = 0.37.*(1+random('norm',0,0.2));
        lagtime = 3.*tau;
        
        lags = [tau]; % Delay times
        tspan = [0,ElapsedTime]; %Timespan for the simulation
        StartE = 0;
        history = [StartE;Damage.*(1+random('norm',0,0.05));0]; %Constant value that is used for the history needed for the delay type problem
        
        options = ddeset('MaxStep',50);
        sol = ddesd(@ddefunction,lags,history,tspan,options); %Invocation of the DDE integrator
        
        [pks,locs] = findpeaks(-sol.yp(2,:));
        
        
        
        if ~isempty(pks)
            TOneContainer(1,kk) = pks(1);
            TOneContainer(2,kk) = sol.x(locs(1));
        end
        
        if length(pks)>1
            TTwoContainer(1,kk) = pks(2);
            TTwoContainer(2,kk) = sol.x(locs(2));
        end
        
        if length(pks)>2
            TThreeContainer(1,kk) = pks(3);
            TThreeContainer(2,kk) = sol.x(locs(3));
        end
        
    end
    
    ScalingTimes(ll) = 1./(1./TD+1./FriedmanTau);
    
    if exist('TOneContainer')
        TOneTimes = TOneContainer(2,:);
        TOnePeaks = TOneContainer(1,TOneTimes>0);
        TOneTimes = TOneTimes(TOneTimes>0);
    else
        TOneTimes = []; TOnePeaks = [];
    end
    
    if exist('TTwoContainer')
        TTwoTimes = TTwoContainer(2,:);
        TTwoPeaks = TTwoContainer(1,TTwoTimes>0);
        TTwoTimes = TTwoTimes(TTwoTimes>0);
    else
        TTwoTimes = []; TTwoPeaks = [];
    end
    
    if exist('TThreeContainer')
        TThreeTimes = TThreeContainer(2,:);
        TThreePeaks = TThreeContainer(1,TThreeTimes>0);
        TThreeTimes = TThreeTimes(TThreeTimes>0);
    else
        TThreeTimes = []; TThreePeaks = [];
    end
    
    CellNumber(:,ll) = [numel(TOneTimes);numel(TTwoTimes);numel(TThreeTimes)]./NumberOfCells.*100;
    PeakTimes(:,ll) = [mean(TOneTimes);mean(TTwoTimes);mean(TThreeTimes)];
    PeakTimesSTDEV(:,ll) = [std(TOneTimes),std(TTwoTimes),std(TThreeTimes)];
    PeakAmplitudes(:,ll) = [mean(TOnePeaks);mean(TTwoPeaks);mean(TThreePeaks)];
    PeakAmplitudesSTDEV(:,ll) = [std(TOnePeaks),std(TTwoPeaks),std(TThreePeaks)];
end

subplot(3,1,1)
plot(IrradiationValues,CellNumber(1,:),'r-s','MarkerFaceColor','r')
hold on
plot(IrradiationValues,CellNumber(2,:),'b-o','MarkerFaceColor','b')
plot(IrradiationValues,CellNumber(3,:),'g--d','MarkerFaceColor','g')
hold off
xlabel('UV dose [J/m^2]')
ylabel('% of cells')
axis([0 inf 0 102])
set(gca,'XTick',[0:10:50])

subplot(3,1,2)
errorbar(IrradiationValues,PeakTimes(1,:)./ScalingTimes,PeakTimesSTDEV(1,:)./ScalingTimes./sqrt(NumberOfCells),'r-s','MarkerFaceColor','r')
hold on
errorbar(IrradiationValues,PeakTimes(2,:)./ScalingTimes,PeakTimesSTDEV(2,:)./ScalingTimes./sqrt(NumberOfCells),'b-o','MarkerFaceColor','b')
errorbar(IrradiationValues,PeakTimes(3,:)./ScalingTimes,PeakTimesSTDEV(3,:)./ScalingTimes./sqrt(NumberOfCells),'g--d','MarkerFaceColor','g')
hold off
xlabel('UV dose [J/m^2]')
ylabel('T_i/T')
axis([0 inf 0 inf])
set(gca,'XTick',[0:10:50])
set(gca,'YTick',[0,1,2,3])

subplot(3,1,3)
errorbar(IrradiationValues,PeakAmplitudes(1,:),PeakAmplitudesSTDEV(1,:)./sqrt(NumberOfCells),'r-s','MarkerFaceColor','r')
hold on
errorbar(IrradiationValues,PeakAmplitudes(2,:),PeakAmplitudesSTDEV(2,:)./sqrt(NumberOfCells),'b-o','MarkerFaceColor','b')
errorbar(IrradiationValues,PeakAmplitudes(3,:),PeakAmplitudesSTDEV(3,:)./sqrt(NumberOfCells),'g--d','MarkerFaceColor','g')
errorbar([20,30,40,50],[0.037,0.045,0.050,0.054],[0.002,0.002,0.002,0.002]./sqrt(NumberOfCells),'r-.o')
hold off
xlabel('UV dose [J/m^2]')
ylabel('<E_i>')
axis([0 inf 0 inf])
set(gca,'XTick',[0:10:50])
set(gca,'YTick',[0:0.01:0.05])



%Defining the subroutine, that is used as the DDEs in the integrator dde23
function vv = ddefunction(tt,yy,ZZ)

global sNull lagtime

gamma = 0.1;
nn = 1;
nnd = 3;
CC = 0.1;

vv = zeros(3,1);

%Actual DDE, yy is xx, ZZ(1) is xx delayed by tau
vv(1) = max(yy(2).^nnd./(1+yy(2).^nnd),0).*(gamma.*heaviside(tt-lagtime) - sNull.*((ZZ(1)).^nn)./(1+(ZZ(1)).^nn));
vv(2) = -CC.*max(yy(2)./(1+yy(2)),0).*max(((yy(1)).^nn)./(1+(yy(1)).^nn),0);
vv(3) = ((yy(1)).^nn)./(1+(yy(1)).^nn);
