function WildTypeHistogram(Irradiation)
% This function plots the peak amplitudes and histogram for the E. coli
% wild type irradiation experiment for 51 cells. The irradiation should be
% entered as the function argument, simply in units of J7m^2 as given in
% the paper.

Damage = Irradiation.*0.11;

%Mean delay time tau dependent on irradiation level
FriedmanTau = 68; %From Friedman et al. paper

%Linear Fit
TDNull = 34.8; TDPrime = 1.3; %From regression to Friedman et al. data, Rsquare = 0.9481
TD = TDNull+TDPrime.*Irradiation;

%2nd degree polynomial fit
%From regression to Friedman et al. data, Rsquare=0.9702
TDNull = 39.0; TDPrime = 0.599; TDPrimePrime = 0.0135;
TD = TDPrimePrime.*Irradiation.^2 + TDPrime.*Irradiation + TDNull;

%Mean tau from Friedman et al. paper relation
MeanTau = FriedmanTau./4.35.*TD./(FriedmanTau+TD);

ElapsedTime = 150;
NumberOfCells = 51;
global sNull lagtime

TOneContainer = zeros(2,NumberOfCells);
TTwoContainer = TOneContainer;
TThreeContainer = TOneContainer;

for kk = 1:NumberOfCells;
    NumberOfCells-kk+1
    
    tau = MeanTau.*(1+random('norm',0,0.03)); %Delay in minutes
    sNull = 0.37.*(1+random('norm',0,0.2));
    lagtime = 3.*tau;%18.5.*(1+random('norm',0,0.16));
    
    lags = [tau]; % Delay times
    tspan = [0,ElapsedTime]; %Timespan for the simulation
    StartE = 0;
    history = [StartE;Damage.*(1+random('norm',0,0.05));0]; %Constant value that is used for the history needed for the delay type problem
    
    options = ddeset('MaxStep',50);
    sol = ddesd(@ddefunction,lags,history,tspan,options); %Invocation of the DDE integrator
    
    [pks,locs] = findpeaks(-sol.yp(2,:));
    if ~isempty(pks)
        TOneContainer(1,kk) = pks(1);
        TOneContainer(2,kk) = sol.x(locs(1));
    end
    
    if length(pks)>1
        TTwoContainer(1,kk) = pks(2);
        TTwoContainer(2,kk) = sol.x(locs(2));
    end
    
    if length(pks)>2
        TThreeContainer(1,kk) = pks(3);
        TThreeContainer(2,kk) = sol.x(locs(3));
    end

end

TOneTimes = TOneContainer(2,:);
TOnePeaks = TOneContainer(1,TOneTimes>0);
TOneTimes = TOneTimes(TOneTimes>0);

disp(sprintf('Amplitude: %f +- %f',mean(TOnePeaks),std(TOnePeaks)))

TTwoTimes = TTwoContainer(2,:);
TTwoPeaks = TTwoContainer(1,TTwoTimes>0);
TTwoTimes = TTwoTimes(TTwoTimes>0);

TThreeTimes = TThreeContainer(2,:);
TThreePeaks = TThreeContainer(1,TThreeTimes>0);
TThreeTimes = TThreeTimes(TThreeTimes>0);

SupportVector = [0:5:ElapsedTime];
[TOneHistN,TOneHistX] = hist(TOneTimes,SupportVector);
[TTwoHistN,TTwoHistX] = hist(TTwoTimes,SupportVector);
[TThreeHistN,TThreeHistX] = hist(TThreeTimes,SupportVector);

subplot(3,1,1:2)
plot(TOneTimes,TOnePeaks,'or',TTwoTimes,TTwoPeaks,'og',TThreeTimes,TThreePeaks,'ob')
xlabel('Time after UV irradiation (min)')
ylabel('RecA Promoter activation')
axis([0 ElapsedTime 0 inf])
set(gca,'XTick',[0:20:140])

subplot(3,1,3)
hold off
bar(TOneHistX,TOneHistN,'r')
hold
bar(TTwoHistX,TTwoHistN,'g')
bar(TThreeHistX,TThreeHistN,'b')
axis([0 ElapsedTime 0 inf])
xlabel('Time after UV irradiation (min)')
ylabel('# of cells')
set(gca,'XTick',[0:20:140])




%Defining the subroutine, that is used as the DDEs in the integrator dde23
function vv = ddefunction(tt,yy,ZZ)

global sNull lagtime

gamma = 0.1;
nn = 1;
nnd = 3;
CC = 0.1;

vv = zeros(3,1);

%Actual DDE, yy is xx, ZZ(1) is xx delayed by tau
vv(1) = max(yy(2).^nnd./(1+yy(2).^nnd),0).*(gamma.*heaviside(tt-lagtime) - sNull.*((ZZ(1)).^nn)./(1+(ZZ(1)).^nn));
vv(2) = -CC.*max(yy(2)./(1+yy(2)),0).*max(((yy(1)).^nn)./(1+(yy(1)).^nn),0);
vv(3) = ((yy(1)).^nn)./(1+(yy(1)).^nn);